@@ -41,11 +41,11 @@ class Wlheadless:
             'dbus-run-session',
             'gnome-kiosk',
             '--wayland',
-            '--no-x11',
-            '--headless'
+            '--headless',
         ]
         self.wlheadless_common = WlheadlessCommon()
         self.xwayland = Xwayland()
+        self.options = self.wlheadless_common.get_command_output(['gnome-kiosk', '-h'])
 
 
     def spawn_client(self, command_args):
@@ -68,7 +68,14 @@ class Wlheadless:
         """Starts the Wayland compositor."""
         wayland_display = 'wayland-' + format(getpid())
         environ['WAYLAND_DISPLAY'] = wayland_display
+        # Add at least one virtual monitor if none is specified
+        if not '--virtual-monitor' in compositor_args:
+            compositor_args.extend(['--virtual-monitor', '1024x768'])
         compositor = self.compositor
+        # The option '--no-x11' might not be supported if mutter was built
+        # without X11 support.
+        if '--no-x11' in self.options:
+            compositor.extend(['--no-x11'])
         compositor.extend(compositor_args)
         compositor.extend(['--wayland-display', format(wayland_display)])
         return self.wlheadless_common.run_compositor(compositor)
