@@ -41,11 +41,11 @@ class Wlheadless:
             'dbus-run-session',
             'mutter',
             '--wayland',
-            '--no-x11',
             '--headless',
         ]
         self.wlheadless_common = WlheadlessCommon()
         self.xwayland = Xwayland()
+        self.options = self.wlheadless_common.get_command_output(['mutter', '-h'])
 
 
     def spawn_client(self, command_args):
@@ -53,6 +53,10 @@ class Wlheadless:
         wayland_display = 'wayland-' + format(getpid())
         environ['WAYLAND_DISPLAY'] = wayland_display
         compositor = self.compositor
+        # The option '--no-x11' might not be supported if mutter was built
+        # without X11 support.
+        if '--no-x11' in self.options:
+            compositor.extend(['--no-x11'])
         compositor.extend(self.compositor_args)
         compositor.extend(['--wayland-display', format(wayland_display)])
         compositor.extend(['--'])
@@ -63,6 +67,8 @@ class Wlheadless:
     def spawn_xwayland(self, xserver_args = []):
         """Helper function to spawn mutter and Xwayland at once."""
         compositor = self.compositor
+        if '--no-x11' in self.options:
+            compositor.extend(['--no-x11'])
         compositor.extend(self.compositor_args)
         compositor.extend(['--'])
         xserver_args.extend(['-fullscreen'])
@@ -76,6 +82,9 @@ class Wlheadless:
 
     def run_compositor(self, compositor_args = []):
         """Starts the Wayland compositor."""
+        # Add at least one virtual monitor if none is specified
+        if not '--virtual-monitor' in compositor_args:
+            compositor_args.extend(['--virtual-monitor', '1024x768'])
         # Just save the given args for when we shall actually spawn the compositor.
         self.compositor_args = compositor_args
         return 0
