@@ -26,6 +26,7 @@ import importlib
 import os
 import subprocess
 import socket
+from shutil import rmtree
 from signal import signal, SIGTERM, SIG_IGN
 from tempfile import mkdtemp
 from time import sleep
@@ -43,13 +44,25 @@ class WlheadlessCommon:
 
 
     def __init__(self):
-        os.setpgrp()
+        try:
+            os.setpgrp()
+        except Exception as error:
+            print(f'Warning, failed to create process group: {error}\n')
         self.xdg_runtime_dir = None
         if not os.getenv('XDG_RUNTIME_DIR'):
             self.xdg_runtime_dir = mkdtemp()
             os.environ['XDG_RUNTIME_DIR'] = self.xdg_runtime_dir
 
 
+    def get_command_output(self, command):
+        try:
+            output = subprocess.check_output(command)
+        except Exception as error:
+            print(f'Failed to run command: {error}\n')
+            return []
+        return (output.decode()).split()
+
+
     def load_compositor(self, compositor):
         try:
             module = importlib.import_module('wlheadless.' + compositor)
@@ -76,7 +89,7 @@ class WlheadlessCommon:
             with subprocess.Popen(command) as proc:
                 proc.wait()
                 return proc.returncode
-        except subprocess.SubprocessError as error:
+        except Exception as error:
             print(f'Failed to run the command: {error}\n')
             return -1
         except KeyboardInterrupt:
@@ -110,7 +123,7 @@ class WlheadlessCommon:
         try:
             proc = subprocess.Popen(compositor)
             return proc.pid
-        except subprocess.SubprocessError as error:
+        except Exception as error:
             print(f'Failed to start the compositor: {error}\n')
             return -1
         except KeyboardInterrupt:
@@ -120,8 +133,9 @@ class WlheadlessCommon:
     def __cleanup_tempdir(self):
         """ Removes our temporary XDG_RUNTIME_DIR directory if empty. """
         if self.xdg_runtime_dir:
+            os.waitpid(-1, 0)
             try:
-                os.rmdir(self.xdg_runtime_dir)
+                rmtree(self.xdg_runtime_dir)
             except OSError as error:
                 print(f'Error removing directory {self.xdg_runtime_dir}: {error}\n')
 
@@ -129,6 +143,9 @@ class WlheadlessCommon:
     def cleanup(self):
         """ Clean-up function """
         handler = signal(SIGTERM, SIG_IGN)
-        os.killpg(os.getpgid(0), SIGTERM)
+        try:
+            os.killpg(os.getpgid(0), SIGTERM)
+        except Exception as error:
+            print(f'Warning, failed to kill process group: {error}\n')
         signal(SIGTERM, handler)
         self.__cleanup_tempdir()
