@@ -42,7 +42,10 @@ class Xwayland:
     def __init__(self):
         self.tempdir = None
         self.xauthfile = None
-        os.setpgrp()
+        try:
+            os.setpgrp()
+        except Exception as error:
+            print(f'Warning, failed to create process group: {error}\n')
 
 
     def run_command(self, command):
@@ -51,7 +54,7 @@ class Xwayland:
             with subprocess.Popen(command) as proc:
                 proc.wait()
                 return proc.returncode
-        except subprocess.SubprocessError as error:
+        except Exception as error:
             print(f'Failed to run the command: {error}\n')
             return -1
         except KeyboardInterrupt:
@@ -71,7 +74,7 @@ class Xwayland:
                 return -1
             os.environ['DISPLAY'] = f':{disp_num}'
             return proc.pid
-        except subprocess.CalledProcessError as error:
+        except Exception as error:
             print(f'Failed to start Xwayland: {error}\n')
             return -1
 
@@ -110,8 +113,8 @@ class Xwayland:
                 if proc.returncode != 0:
                     print('Failed to add xauth entry!\n')
                 return proc.returncode
-        except subprocess.SubprocessError:
-            print('Failed to spawn xauth\n!')
+        except Exception as error:
+            print(f'Failed to execute xauth: {error}\n - Is xauth installed?\n')
             return -1
 
 
@@ -121,8 +124,8 @@ class Xwayland:
         try:
             with subprocess.Popen(xauth_command_line) as proc:
                 proc.wait()
-        except subprocess.SubprocessError:
-            print('Failed to run xauth to remove the entry in Xauthority\n!')
+        except Exception as error:
+            print(f'Failed to run xauth to remove the entry in Xauthority: {error}\n')
 
 
     def setup_tempdir(self):
@@ -142,7 +145,10 @@ class Xwayland:
     def cleanup(self):
         """ Clean-up function. """
         handler = signal(SIGTERM, SIG_IGN)
-        os.killpg(os.getpgid(0), SIGTERM)
+        try:
+            os.killpg(os.getpgid(0), SIGTERM)
+        except Exception as error:
+            print(f'Warning, failed to kill process group: {error}\n')
         signal(SIGTERM, handler)
         self.remove_xauth_entry()
         self.cleanup_xauth()
